@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union
 
 import httpx
@@ -51,7 +52,7 @@ def _get_kwargs(
 
 
 def _parse_response(*, response: httpx.Response) -> Optional[IncidentsV2ListResponseBody]:
-    if response.status_code == 200:
+    if response.status_code == HTTPStatus.OK:
         response_200 = IncidentsV2ListResponseBody.from_dict(response.json())
 
         return response_200
@@ -60,7 +61,7 @@ def _parse_response(*, response: httpx.Response) -> Optional[IncidentsV2ListResp
 
 def _build_response(*, response: httpx.Response) -> Response[IncidentsV2ListResponseBody]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=_parse_response(response=response),
